@@ -9,15 +9,16 @@ Uloz::Uloz(QObject *parent) :
 }
 
 void Uloz::getCaptcha(const QString &key) {
-    m_challenge = key;
+    this->setChallenge(key);
     QUrl url(QString("http://img.uloz.to/captcha/%1.png").arg(key));
     QNetworkRequest request(url);
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(onCaptchaDownloaded()));
+    this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
 }
 
 void Uloz::onCaptchaDownloaded() {
-    QNetworkReply *reply = qobject_cast<QNetworkReply*>(sender());
+    QNetworkReply *reply = qobject_cast<QNetworkReply*>(this->sender());
 
     if (!reply) {
         emit error(NetworkError);
@@ -27,7 +28,7 @@ void Uloz::onCaptchaDownloaded() {
     int statusCode = reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
 
     if (statusCode == 200) {
-        emit gotCaptcha(reply->readAll());
+        emit captchaReady(reply->readAll());
     }
     else {
         this->reportError(statusCode);
@@ -55,4 +56,10 @@ void Uloz::reportError(int errorCode) {
     }
 }
 
+bool Uloz::cancelCurrentOperation() {
+    emit currentOperationCancelled();
+
+    return true;
+}
+
 Q_EXPORT_PLUGIN2(ulozrecaptcha, Uloz)
